import os

from TwitterAPI import TwitterAPI, TwitterOAuth


def run():
    print("Hello friend …")

    if not os.path.isfile('twacapic_credentials.py'):
        print("Please enter your API key:")
        consumer_key = input()
        print("Please enter your API secret:")
        consumer_secret = input()

        with open('twacapic_credentials.txt', 'a') as keyfile:
            keyfile.writelines([
                f'consumer_key = {consumer_key}\n',
                f'consumer_secret = {consumer_secret}\n',
                'access_token_key = NOT_NECESSARY\n',
                'access_token_secret = NOT_NECESSARY\n'
            ])

    keys = TwitterOAuth.read_file('twacapic_credentials.txt')
    print(keys.consumer_key, keys.consumer_key)

    api = TwitterAPI(keys.consumer_key, keys.consumer_secret, auth_type='oAuth2', api_version='2')

    r = api.request('tweets/search/all', {'query': 'from:flxvctr'})

    print(r.text)


if __name__ == '__main__':
    run()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['twacapic']

package_data = \
{'': ['*']}

install_requires = \
['TwitterAPI>=2.6.9,<3.0.0']

entry_points = \
{'console_scripts': ['twacapic = twacapic.main:run']}

setup_kwargs = {
    'name': 'twacapic',
    'version': '0.1.3.3',
    'description': 'A Twitter Academic API Client',
    'long_description': '# twacapic\n\nTwitter Academic API Client\n\nIn development. Not even ready for experimental use!\n\n\n## Installation\n\nInstall via pip:\n\n`pip install twacapic`\n\n\n## Dev Install\n\n1. Install [poetry](https://python-poetry.org/docs/#installation)\n2. Clone repository\n3. In the directory run `poetry install`\n4. Run `poetry shell` to start development virtualenv\n\n',
    'author': 'Felix Victor Münch',
    'author_email': 'f.muench@leibniz-hbi.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Leibniz-HBI/twacapic',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
